package com.rehan.yodosdk;

import android.app.Activity;

import androidx.annotation.NonNull;

import com.rehan.yodosdk.Banner.*;
import com.rehan.yodosdk.Inter.*;
import com.rehan.yodosdk.Reward.*;
import com.rehan.yodosdk.RewardInter.*;
import com.rehan.yodosdk.nativead.*;
import com.yodo1.mas.Yodo1Mas;
import com.yodo1.mas.helper.model.Yodo1MasAdBuildConfig;

import java.util.HashMap;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * YodosdkPlugin
 */
public class YodosdkPlugin implements ActivityAware, FlutterPlugin {

    public static boolean isInit = false;
    private MethodChannel channel;
    private MethodChannel interChannel;
    private MethodChannel rewardChannel;
    private MethodChannel rewardInterChannel;
    private Activity context;
    NativeAdFactory nativeAdFactory;
    BannerAdFactory bannerAdFactory;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "yodosdk");
        interChannel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "interChannel");
        rewardChannel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "rewardChannel");
        rewardInterChannel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "rewardChannel");
        nativeAdFactory = new NativeAdFactory(flutterPluginBinding.getBinaryMessenger());
        flutterPluginBinding.getPlatformViewRegistry()
                .registerViewFactory("nativeAd", nativeAdFactory);

        bannerAdFactory = new BannerAdFactory(flutterPluginBinding.getBinaryMessenger());
        flutterPluginBinding.getPlatformViewRegistry()
                .registerViewFactory("bannerAd", bannerAdFactory);

        channel.setMethodCallHandler(new MethodCallHandler() {
            @Override
            public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
                if (call.method.equals("initSDK")) {
                    HashMap arguments = (HashMap) call.arguments;
                    String appId = arguments.get("appId").toString();
                    boolean showPrivacyDialog = (boolean) arguments.get("showPrivacyDialog");
                    YodoInterHelper.setMethodChannel(interChannel);
                    YodoRewardHelper.setMethodChannel(rewardChannel);
                    YodoRewardInterHelper.setMethodChannel(rewardInterChannel);
                    try {
                        System.out.println("Init Sdk:===>");
                        Yodo1Mas.getInstance().setCOPPA(false);
                        Yodo1Mas.getInstance().setGDPR(true);
                        Yodo1Mas.getInstance().setCCPA(false);
                        YodoCoreHelper.initYodoSdk(channel, context, appId);
                        if (showPrivacyDialog) {
                            Yodo1MasAdBuildConfig yodo1MasAdBuildConfig =
                                    new Yodo1MasAdBuildConfig
                                            .Builder()
                                            .enableUserPrivacyDialog(true)
                                            .build();
                            Yodo1Mas.getInstance().setAdBuildConfig(yodo1MasAdBuildConfig);
                        }

                        // Load Default Ad in Cache
                        YodoInterHelper.loadOnly(context);
                        YodoRewardHelper.loadOnly(context);
//                        YodoRewardInterHelper.loadOnly(context);

                    } catch (Exception e) {
                        System.out.println(e.toString());
                    }
                }
                if (call.method.equals("loadInter")) {
                    YodoInterHelper.loadAndShowInter(context);
                }
                if (call.method.equals("loadReward")) {
                    YodoRewardHelper.loadAndShowReward(context);
                }
                if (call.method.equals("loadInterReward")) {
                    YodoRewardInterHelper.loadAndShowRewardInter(context);
                }
                if (call.method.equals("getPlatformVersion")) {
                    result.success("Android " + android.os.Build.VERSION.RELEASE);
                } else {
                    result.notImplemented();
                }
            }
        });
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        context = binding.getActivity();
        nativeAdFactory.setActivity(context);
        bannerAdFactory.setActivity(context);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {

    }


    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}
