import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

import 'package:yodosdk/Constants.dart';

class YodoNativeAd extends StatefulWidget {
  /// Unity Ad Placement ID

  /// Size of the Native ad.
  final NativeSize size;
  final String backgroundColor;

  final void Function()? onLoad;

  final void Function()? onClosed;

  final void Function(String errorMessage)? onLoadFailed;

  /// This widget is used to contain Native Ads.
  const YodoNativeAd({
    Key? key,
    this.size = NativeSize.nativeSmall,
    this.backgroundColor = "",
    this.onLoad,
    this.onClosed,
    this.onLoadFailed,
  }) : super(key: key);

  @override
  _YodoNativeAdState createState() => _YodoNativeAdState();
}

class _YodoNativeAdState extends State<YodoNativeAd> {
  bool _isLoaded = false;

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return SizedBox(
        height: widget.size.height + 0.0,
        width: widget.size.width + 0.0,
        child: OverflowBox(
          maxHeight: _isLoaded ? widget.size.height + 0.0 : 1,
          minHeight: 0.1,
          alignment: Alignment.center,
          child: AndroidView(
            viewType: nativeAdChannel,
            creationParams: <String, dynamic>{
              nativesize: widget.size.size,
              nativecolor: widget.backgroundColor,
            },
            creationParamsCodec: const StandardMessageCodec(),
            onPlatformViewCreated: _onNativeAdViewCreated,
          ),
        ),
      );
    }
    if (defaultTargetPlatform == TargetPlatform.iOS) {
      return SizedBox(
          height: widget.size.height + 0.0,
          width: widget.size.width + 0.0,
          child: OverflowBox(
            maxHeight: _isLoaded ? widget.size.height + 0.0 : 1,
            minHeight: 0.1,
            alignment: Alignment.center,
            child: UiKitView(
              viewType: nativeAdChannel,
              creationParams: <String, dynamic>{
                nativesize: widget.size.size,
                nativecolor: widget.backgroundColor,
              },
              creationParamsCodec: const StandardMessageCodec(),
              onPlatformViewCreated: _onNativeAdViewCreated,
            ),
          ));
    }

    return Container();
  }

  void _onNativeAdViewCreated(int id) {
    final channel = MethodChannel('${nativeAdChannel}_$id');
    channel.setMethodCallHandler((call) async {
      switch (call.method) {
        case nativeLoadErrorMethod:
          widget.onLoadFailed?.call(
            call.arguments[errorMessageParameter],
          );
          break;

        case nativeLoadedMethod:
          if (widget.onLoad != null) {
            widget.onLoad!();
          }
          setState(() {
            _isLoaded = true;
          });
          break;
        case nativeCloseMethod:
          if (widget.onClosed != null) {
            widget.onClosed!();
          }
          break;
      }
    });
  }
}

/// Defines the size of Native Ad.
class NativeSize {
  final String size;
  final int width;
  final int height;

  static const NativeSize nativeSmall =
      NativeSize(size: "NativeSmall", width: 300, height: 100);
  static const NativeSize nativeLarge =
      NativeSize(size: "NativeLarge", width: 600, height: 335);

  const NativeSize(
      {this.width = 300, this.height = 100, this.size = "NativeSmall"});
}

enum NativeAdState {
  loaded,
  loadError,
  closed,
}
