import 'package:flutter/services.dart';
import 'package:yodosdk/Reward/RewardAdCallbacks.dart';

class RewardHelper {
  static final RewardHelper _singleton = RewardHelper._internal();
  static const methodChannel = MethodChannel("rewardChannel");

  factory RewardHelper() {
    return _singleton;
  }

  static initRewardListeners(RewardAdCallbacks rewardAdCallbacks) {
    methodChannel.setMethodCallHandler(
      (call) {
        return myUtilsHandler(call, rewardAdCallbacks);
      },
    );
  }

  static initRewardInterListeners(RewardAdCallbacks rewardAdCallbacks) {
    methodChannel.setMethodCallHandler(
      (call) {
        return myInterRewardHandler(call, rewardAdCallbacks);
      },
    );
  }

  static Future<dynamic> myInterRewardHandler(
    MethodCall methodCall,
    RewardAdCallbacks rewardAdCallbacks,
  ) async {
    print("Printing Reward Method Name");
    print(methodCall.method);
    switch (methodCall.method) {
      case "loaded_reward_inter":
        rewardAdCallbacks.onLoad(methodCall.arguments);
        break;
      case "fail_load_reward_inter":
        print(methodCall.arguments);
        rewardAdCallbacks.onAdLoadFail(methodCall.arguments);
        break;
      case "open_reward_inter":
        rewardAdCallbacks.onAdOpen(methodCall.arguments);
        break;
      case "fail_open_reward_inter":
        rewardAdCallbacks.onAdOpenFail(methodCall.arguments);
        break;
      case "close_reward_inter":
        print("Reward Close =========>");
        rewardAdCallbacks.onClose(methodCall.arguments);
        break;
      case "rewarded_reward_inter":
        print("Reward Rewarded =========>");
        rewardAdCallbacks.onRewardEarned(methodCall.arguments);
        break;
      default:
        // rewardAdCallbacks.onClose(methodCall.arguments);
        print("Default Case ${methodCall.method}");
    }
  }

  static Future<dynamic> myUtilsHandler(
    MethodCall methodCall,
    RewardAdCallbacks rewardAdCallbacks,
  ) async {
    switch (methodCall.method) {
      case "loaded_reward":
        rewardAdCallbacks.onLoad(methodCall.arguments);
        break;
      case "fail_load_reward":
        rewardAdCallbacks.onAdLoadFail(methodCall.arguments);
        break;
      case "open_reward":
        rewardAdCallbacks.onAdOpen(methodCall.arguments);
        break;
      case "fail_open_reward":
        rewardAdCallbacks.onAdOpenFail(methodCall.arguments);
        break;
      case "close_reward":
        rewardAdCallbacks.onClose(methodCall.arguments);
        break;
      case "rewarded_reward":
        rewardAdCallbacks.onRewardEarned(methodCall.arguments);
        break;
      default:
        // rewardAdCallbacks.onClose(methodCall.arguments);
        print("Default Case ${methodCall.method}");
    }
  }

  RewardHelper._internal();
}
