import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:yodosdk/Banner/BannerAdCallback.dart';
import 'package:yodosdk/Banner/Yodo_BannerAd.dart';
import 'package:yodosdk/Init/InitAdCallback.dart';
import 'package:yodosdk/Inter/FullScreenAdCallbacks.dart';
import 'package:yodosdk/Inter/InterHelper.dart';
import 'package:yodosdk/Native/YodoNativeAd.dart';
import 'package:yodosdk/Reward/RewardAdCallbacks.dart';
import 'package:yodosdk/Reward/RewardHelper.dart';

import 'Native/NativeAdCallback.dart';
import 'yodosdk_platform_interface.dart';

class Yodosdk {
  static const methodChannel = MethodChannel("yodosdk");

  Future<String?> getPlatformVersion() {
    return YodosdkPlatform.instance.getPlatformVersion();
  }

  static getNative(
      {required NativeAdCallback nativeAdCallback,
      NativeSize size = NativeSize.nativeSmall}) {
    return YodoNativeAd(
      onClosed: nativeAdCallback.onClosed,
      onLoad: nativeAdCallback.onLoad,
      onLoadFailed: nativeAdCallback.onLoadFailed,
      size: size,
    );
  }

  static getBanner({
    required BannerAdCallback bannerAdCallback,
    BannerSize size = BannerSize.largeBanner,
  }) {
    return YodoBannerAd(
      onClosed: bannerAdCallback.onClosed,
      onLoad: bannerAdCallback.onLoad,
      onLoadFailed: bannerAdCallback.onLoadFailed,
      size: size,
      onOpen: bannerAdCallback.onOpen,
      onOpenFailed: bannerAdCallback.onOpenFail,
    );
  }

  static initSdk({
    required String appId,
    bool preLoadAds = false,
    bool showPrivacyDialog = true,
    required InitAdCallback initAdCallback,
  }) async {
    try {
      await methodChannel.invokeMethod("initSDK", {
        "appId": appId,
        "preLoadAds": preLoadAds,
        "showPrivacyDialog": showPrivacyDialog,
      });
    } catch (error) {}
    methodChannel.setMethodCallHandler(
      (call) {
        return initHandler(call, initAdCallback);
      },
    );
  }

  static Future<dynamic> initHandler(
    MethodCall methodCall,
    InitAdCallback initAdCallback,
  ) async {
    switch (methodCall.method) {
      case "init_success":
        initAdCallback.onSuccess();
        break;
      case "init_error":
        initAdCallback.onError(
          json.encode(methodCall.arguments),
        );
        break;
      default:
        print("Default Case ${methodCall.arguments}");
    }
  }

  static loadAndShowInter(
      {required FullScreenAdCallbacks fullScreenAdCallbacks}) async {
    try {
      await methodChannel.invokeMethod("loadInter");
    } catch (e) {}
    InterHelper.initInterListeners(fullScreenAdCallbacks);
  }

  static loadAndShowReward(
      {required RewardAdCallbacks rewardAdCallbacks}) async {
    RewardHelper.initRewardListeners(rewardAdCallbacks);
    try {
      await methodChannel.invokeMethod("loadReward");
    } catch (e) {
      print(e);
    }
  }

  static loadAndShowRewardInter(
      {required RewardAdCallbacks rewardAdCallbacks}) async {
    RewardHelper.initRewardInterListeners(rewardAdCallbacks);
    try {
      await methodChannel.invokeMethod("loadInterReward");
    } catch (e) {
      print(e);
    }
  }

  static showPrivacyDialog() async {
    await methodChannel.invokeMethod("showPrivacyDialog");
  }
}
